import React from "react";
import Reflux from "reflux";
import {Label} from "react-bootstrap";

import Actions from "../../actions/Actions";
import I18nWrapper from "../../i18n/I18nWrapper";
import injectIntl from "../../utils/injectIntl";
import ReportsTable from "./ReportsTable";
import TagStore from "../../stores/TagStore";

class FilterableReportsTable extends Reflux.Component {
    constructor(props) {
        super(props);
        this.i18n = props.i18n;
        this.state = {
            filterTags: []
        };
        this.store = TagStore;
    }

    componentDidMount() {
        Actions.loadTags();
    }

    _toggleTagInFilter = (tag) => {
        const index = this.state.filterTags.indexOf(tag.name),
            tagsCopy = this.state.filterTags.slice();
        if (index !== -1) {
            tagsCopy.splice(index, 1);
        } else {
            tagsCopy.push(tag.name);
        }
        this.setState({filterTags: tagsCopy});
    };

    _filterReports(reports) {
        if (this.state.filterTags.length === 0) {
            return reports;
        }
        const copy = [],
            filterTags = this.state.filterTags;
        for (let i = 0, len = reports.length; i < len; i++) {
            const tags = reports[i].tags ? reports[i].tags : [];
            for (let j = 0, jLen = tags.length; j < jLen; j++) {
                if (filterTags.indexOf(tags[j]) !== -1) {
                    copy.push(reports[i]);
                    break;
                }
            }
        }
        return copy;
    }

    render() {
        const props = {...this.props};
        props.reports = this._filterReports(props.reports);

        return <div>
            <div>
                <label className='control-label'>{this.i18n('reports.filter.tags')}</label>
            </div>
            <div className='tags filter'>
                {this._renderTags()}
            </div>
            <ReportsTable {...props}/>
        </div>;
    }

    _renderTags() {
        const tags = this.state.tags ? this.state.tags : [],
            filterTags = this.state.filterTags,
            elements = [];
        for (let i = 0, len = tags.length; i < len; i++) {
            const active = filterTags.indexOf(tags[i].name) !== -1;
            elements.push(<Label key={tags[i].name} onClick={() => this._toggleTagInFilter(tags[i])}
                                 bsStyle={active ? 'success' : 'default'}
                                 title={this.i18n(active ? 'reports.filter.tags.deactivate.tooltip' : 'reports.filter.tags.activate.tooltip')}>
                {tags[i].name}
            </Label>);
        }
        return elements;
    }
}

export default injectIntl(I18nWrapper(FilterableReportsTable));
