'use strict';

import React from "react";
import PropTypes from "prop-types";
import Reflux from "reflux";
import Typeahead from "react-bootstrap-typeahead";
import JsonLdUtils from "jsonld-utils";

import Actions from "../../../actions/Actions";
import Constants from "../../../constants/Constants";
import I18nWrapper from "../../../i18n/I18nWrapper";
import injectIntl from "../../../utils/injectIntl";
import OptionsStore from "../../../stores/OptionsStore";
import TypeaheadResultList from "../../typeahead/TypeaheadResultList";
import Utils from "../../../utils/Utils";

class OccurrenceType extends Reflux.Component {
    constructor(props) {
        super(props);
        this.i18n = props.i18n;
        this.state = {};
        this.store = OptionsStore;
        this.storeKeys = [Constants.OPTIONS.OCCURRENCE_TYPE];
    }

    componentDidMount() {
        Actions.loadOptions(Constants.OPTIONS.OCCURRENCE_TYPE);
    }

    _onOptionSelected = (option) => {
        this.props.onChange({type: option.id});
    };

    _prepareOptions() {
        const options = this.state[Constants.OPTIONS.OCCURRENCE_TYPE];
        if (!options) {
            return [];
        }
        return JsonLdUtils.processTypeaheadOptions(options, this.props.intl);
    }

    render() {
        const occurrence = this.props.occurrence,
            options = this._prepareOptions(),
            value = occurrence.type ? Utils.idToName(occurrence.type, options) : '';
        return <Typeahead label={this.i18n('occurrence.type') + '*'} title={this.i18n('occurrence.type')}
                          options={options} onOptionSelected={this._onOptionSelected} size='small'
                          filterOption='name' value={value} placeholder={this.i18n('occurrence.type')}
                          displayOption='name' formInputOption='id' customListComponent={TypeaheadResultList}
                          optionsButton/>;
    }
}

OccurrenceType.propTypes = {
    occurrence: PropTypes.object.isRequired,
    onChange: PropTypes.func.isRequired
};

export default injectIntl(I18nWrapper(OccurrenceType));
